# Cookiecutter Python Hello-world for SAM based Serverless App

A cookiecutter template to create a Python Hello world boilerplate using [Serverless Application Model (SAM)](https://github.com/awslabs/serverless-application-model).

## Requirements

* [AWS SAM CLI](https://github.com/awslabs/aws-sam-cli)

## Usage

Generate a boilerplate template in your current project directory using the following syntax:

* **Python 3.7**: `sam init --runtime python3.7`
* **Python 3.8**: `sam init --runtime python3.8`
* **Python 3.9**: `sam init --runtime python3.9`

> **NOTE**: ``--name`` allows you to specify a different project folder name (`sam-app` is the default)


# Credits

* This project has been generated with [Cookiecutter](https://github.com/audreyr/cookiecutter)
